<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hant">
<context>
    <name>KvantumPreviewBase</name>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="14"/>
        <source>Kvantum Preview</source>
        <translation>Kvantum 預覽</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="29"/>
        <source>Push buttons</source>
        <translation>按鈕</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="77"/>
        <source>Toggle
push
button

with
height
greater
than
width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="95"/>
        <location filename="../../KvantumPreviewBase.ui" line="105"/>
        <source>Simple push button</source>
        <translation>簡易按鈕</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="112"/>
        <location filename="../../KvantumPreviewBase.ui" line="128"/>
        <source>Toggle push button</source>
        <translation>切換按鈕</translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="141"/>
        <location filename="../../KvantumPreviewBase.ui" line="152"/>
        <source>Multi-line
 push button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="160"/>
        <location filename="../../KvantumPreviewBase.ui" line="180"/>
        <source>Push button
with 32px folder icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="210"/>
        <location filename="../../KvantumPreviewBase.ui" line="224"/>
        <source>Default
push button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="266"/>
        <source>Flat buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="279"/>
        <source>Button Box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="361"/>
        <source>Tool buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="369"/>
        <location filename="../../KvantumPreviewBase.ui" line="446"/>
        <source>Simple toolbutton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="453"/>
        <location filename="../../KvantumPreviewBase.ui" line="464"/>
        <source>Multi-line
toolbutton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="472"/>
        <location filename="../../KvantumPreviewBase.ui" line="495"/>
        <source>Toggle toolbutton
with an arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="560"/>
        <location filename="../../KvantumPreviewBase.ui" line="584"/>
        <source>Toolbutton with 32px SVG icon
and text below</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="605"/>
        <location filename="../../KvantumPreviewBase.ui" line="626"/>
        <source>Toolbutton with text below
and arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="644"/>
        <location filename="../../KvantumPreviewBase.ui" line="665"/>
        <source>Toolbutton with icon at the side
and arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="683"/>
        <location filename="../../KvantumPreviewBase.ui" line="710"/>
        <source>Toggle toolbutton with icon,
ordinary arrow
and dropdown menu arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="515"/>
        <location filename="../../KvantumPreviewBase.ui" line="539"/>
        <source>Toolbutton with 32px PNG icon
beside text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="402"/>
        <source>Toggle
tool
button

with
height
greater
than
width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="791"/>
        <source>Auto-raise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="812"/>
        <source>Radio/Check buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="833"/>
        <location filename="../../KvantumPreviewBase.ui" line="846"/>
        <source>Simple radio button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="856"/>
        <location filename="../../KvantumPreviewBase.ui" line="867"/>
        <source>Multi-line
radio button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="878"/>
        <location filename="../../KvantumPreviewBase.ui" line="904"/>
        <source>Radio button with 32px SVG icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="927"/>
        <location filename="../../KvantumPreviewBase.ui" line="940"/>
        <source>Simple check box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="950"/>
        <location filename="../../KvantumPreviewBase.ui" line="961"/>
        <source>Multi-line
check box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="969"/>
        <location filename="../../KvantumPreviewBase.ui" line="982"/>
        <source>Tri-state check box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="992"/>
        <location filename="../../KvantumPreviewBase.ui" line="1006"/>
        <source>Check box with icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1062"/>
        <source>Combos/Spins/Inputs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1096"/>
        <location filename="../../KvantumPreviewBase.ui" line="1182"/>
        <location filename="../../KvantumPreviewBase.ui" line="1251"/>
        <location filename="../../KvantumPreviewBase.ui" line="1365"/>
        <location filename="../../KvantumPreviewBase.ui" line="1437"/>
        <location filename="../../KvantumPreviewBase.ui" line="1495"/>
        <source>Frameless (no difference)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1107"/>
        <location filename="../../KvantumPreviewBase.ui" line="1146"/>
        <source>Standard combo box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1116"/>
        <location filename="../../KvantumPreviewBase.ui" line="1155"/>
        <source>Standard combo box 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1124"/>
        <location filename="../../KvantumPreviewBase.ui" line="1160"/>
        <source>Standard combo box 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1129"/>
        <location filename="../../KvantumPreviewBase.ui" line="1165"/>
        <source>Standard combo box 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1134"/>
        <location filename="../../KvantumPreviewBase.ui" line="1170"/>
        <source>Standard combo box 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1191"/>
        <location filename="../../KvantumPreviewBase.ui" line="1260"/>
        <location filename="../../KvantumPreviewBase.ui" line="1374"/>
        <location filename="../../KvantumPreviewBase.ui" line="1446"/>
        <source>Frameless 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1196"/>
        <location filename="../../KvantumPreviewBase.ui" line="1265"/>
        <location filename="../../KvantumPreviewBase.ui" line="1379"/>
        <location filename="../../KvantumPreviewBase.ui" line="1451"/>
        <source>Frameless 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1201"/>
        <location filename="../../KvantumPreviewBase.ui" line="1270"/>
        <location filename="../../KvantumPreviewBase.ui" line="1384"/>
        <location filename="../../KvantumPreviewBase.ui" line="1456"/>
        <source>Frameless 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1206"/>
        <location filename="../../KvantumPreviewBase.ui" line="1275"/>
        <location filename="../../KvantumPreviewBase.ui" line="1389"/>
        <location filename="../../KvantumPreviewBase.ui" line="1461"/>
        <source>Frameless 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1211"/>
        <location filename="../../KvantumPreviewBase.ui" line="1394"/>
        <source>Frameless 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1216"/>
        <location filename="../../KvantumPreviewBase.ui" line="1399"/>
        <source>Frameless 6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1221"/>
        <location filename="../../KvantumPreviewBase.ui" line="1404"/>
        <source>Frameless 7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1226"/>
        <location filename="../../KvantumPreviewBase.ui" line="1409"/>
        <source>Frameless 8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1231"/>
        <location filename="../../KvantumPreviewBase.ui" line="1414"/>
        <source>Frameless 9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1236"/>
        <location filename="../../KvantumPreviewBase.ui" line="1419"/>
        <source>Frameless 10</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1287"/>
        <location filename="../../KvantumPreviewBase.ui" line="1326"/>
        <source>Editable combo box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1296"/>
        <location filename="../../KvantumPreviewBase.ui" line="1335"/>
        <source>Editable combo box 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1301"/>
        <location filename="../../KvantumPreviewBase.ui" line="1340"/>
        <source>Editable combo box 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1306"/>
        <location filename="../../KvantumPreviewBase.ui" line="1345"/>
        <source>Editable combo box 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1311"/>
        <location filename="../../KvantumPreviewBase.ui" line="1350"/>
        <source>Editable combo box 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1469"/>
        <location filename="../../KvantumPreviewBase.ui" line="1482"/>
        <source>Line-edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="1561"/>
        <source>Sliders/Scrolls/Progress/Dial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2118"/>
        <source>Containers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2139"/>
        <source>Header 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2148"/>
        <source>Header 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2156"/>
        <source>Header 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2161"/>
        <location filename="../../KvantumPreviewBase.ui" line="2259"/>
        <source>3rd Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2169"/>
        <location filename="../../KvantumPreviewBase.ui" line="2247"/>
        <source>2nd Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2173"/>
        <location filename="../../KvantumPreviewBase.ui" line="2209"/>
        <source>2nd Child</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2178"/>
        <location filename="../../KvantumPreviewBase.ui" line="2214"/>
        <source>1st Child</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2184"/>
        <location filename="../../KvantumPreviewBase.ui" line="2232"/>
        <source>1st Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2204"/>
        <source>3rd Child</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2502"/>
        <source>Row 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2507"/>
        <source>Row 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2512"/>
        <source>Column 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2520"/>
        <source>Column 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2525"/>
        <source>0-0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2533"/>
        <source>0-1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2541"/>
        <source>1-0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2549"/>
        <source>1-1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2191"/>
        <location filename="../../KvantumPreviewBase.ui" line="2194"/>
        <source>Editable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2221"/>
        <source>Non-Editable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2269"/>
        <source>Subwindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2316"/>
        <source>Panel frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2335"/>
        <location filename="../../KvantumPreviewBase.ui" line="2476"/>
        <location filename="../../KvantumPreviewBase.ui" line="2568"/>
        <source>GroupBox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2355"/>
        <location filename="../../KvantumPreviewBase.ui" line="2407"/>
        <location filename="../../KvantumPreviewBase.ui" line="2701"/>
        <location filename="../../KvantumPreviewBase.ui" line="2778"/>
        <location filename="../../KvantumPreviewBase.ui" line="2826"/>
        <source>Tab 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2361"/>
        <source>Page 1 (disabled)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2373"/>
        <location filename="../../KvantumPreviewBase.ui" line="2421"/>
        <location filename="../../KvantumPreviewBase.ui" line="2719"/>
        <location filename="../../KvantumPreviewBase.ui" line="2792"/>
        <location filename="../../KvantumPreviewBase.ui" line="2840"/>
        <source>Tab 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2379"/>
        <source>Page 2 (disabled)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2413"/>
        <location filename="../../KvantumPreviewBase.ui" line="2606"/>
        <location filename="../../KvantumPreviewBase.ui" line="2661"/>
        <location filename="../../KvantumPreviewBase.ui" line="2784"/>
        <location filename="../../KvantumPreviewBase.ui" line="2832"/>
        <source>Page 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2427"/>
        <location filename="../../KvantumPreviewBase.ui" line="2634"/>
        <location filename="../../KvantumPreviewBase.ui" line="2674"/>
        <location filename="../../KvantumPreviewBase.ui" line="2725"/>
        <location filename="../../KvantumPreviewBase.ui" line="2798"/>
        <location filename="../../KvantumPreviewBase.ui" line="2846"/>
        <source>Page 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2451"/>
        <source>Stack widget (page1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2465"/>
        <source>Stack Widget (page2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2482"/>
        <source>Group box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2560"/>
        <source>Dock Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2577"/>
        <source>Checkable group box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2612"/>
        <source>Tool Box</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2707"/>
        <source>Document mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2745"/>
        <source>Box frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2875"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2879"/>
        <source>&amp;Submenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2899"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2919"/>
        <source>toolBar_2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2941"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2944"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2947"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2955"/>
        <source>&amp;Checkbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2968"/>
        <source>Toggle Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2971"/>
        <source>Toggle layout direction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2983"/>
        <source>&amp;Doc Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2986"/>
        <source>Show tabs in the document mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="2998"/>
        <source>Menu Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3001"/>
        <source>Hold pressed to show a menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3012"/>
        <source>C&amp;heckbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3020"/>
        <source>&amp;Radio button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../KvantumPreviewBase.ui" line="3028"/>
        <source>Radio &amp;button</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
